==> ksonnet-0.11.0.tar.gz: ksonnet-0.11.0/docs/cli-reference/ks.md <==
## ks

Configure your application to deploy to a Kubernetes cluster

### Synopsis


You can use the `ks` commands to write, share, and deploy your Kubernetes
application configuration to remote clusters.

----


```
ks [flags]
```

### Options

```
  -h, --help                 help for ks
  -v, --verbose count[=-1]   Increase verbosity. May be given multiple times.
```

### SEE ALSO

* [ks apply](ks_apply.md)	 - Apply local Kubernetes manifests (components) to remote clusters
* [ks component](ks_component.md)	 - Manage ksonnet components
* [ks delete](ks_delete.md)	 - Remove component-specified Kubernetes resources from remote clusters
* [ks diff](ks_diff.md)	 - Compare manifests, based on environment or location (local or remote)
* [ks env](ks_env.md)	 - Manage ksonnet environments
* [ks generate](ks_generate.md)	 - Use the specified prototype to generate a component manifest
* [ks import](ks_import.md)	 - Import manifest
* [ks init](ks_init.md)	 - Initialize a ksonnet application
* [ks module](ks_module.md)	 - Manage ksonnet modules
* [ks param](ks_param.md)	 - Manage ksonnet parameters for components and environments
* [ks pkg](ks_pkg.md)	 - Manage packages and dependencies for the current ksonnet application
* [ks prototype](ks_prototype.md)	 - Instantiate, inspect, and get examples for ksonnet prototypes
* [ks registry](ks_registry.md)	 - Manage registries for current project
* [ks show](ks_show.md)	 - Show expanded manifests for a specific environment.
* [ks upgrade](ks_upgrade.md)	 - Upgrade ks configuration
* [ks validate](ks_validate.md)	 - Check generated component manifests against the server's API
* [ks version](ks_version.md)	 - Print version information for this ksonnet binary

==> ksonnet-0.13.1.tar.gz: ksonnet-0.13.1/docs/cli-reference/ks.md <==
## ks

Configure your application to deploy to a Kubernetes cluster

### Synopsis


You can use the `ks` commands to write, share, and deploy your Kubernetes
application configuration to remote clusters.

----
	

```
ks [flags]
```

### Options

```
      --dir string        Ksonnet application root to use; Defaults to CWD
  -h, --help              help for ks
      --tls-skip-verify   Skip verification of TLS server certificates
  -v, --verbose count     Increase verbosity. May be given multiple times.
```

### SEE ALSO

* [ks apply](ks_apply.md)	 - Apply local Kubernetes manifests (components) to remote clusters
* [ks component](ks_component.md)	 - Manage ksonnet components
* [ks delete](ks_delete.md)	 - Remove component-specified Kubernetes resources from remote clusters
* [ks diff](ks_diff.md)	 - Compare manifests, based on environment or location (local or remote)
* [ks env](ks_env.md)	 - Manage ksonnet environments
* [ks generate](ks_generate.md)	 - Use the specified prototype to generate a component manifest
* [ks import](ks_import.md)	 - Import manifest
* [ks init](ks_init.md)	 - Initialize a ksonnet application
* [ks module](ks_module.md)	 - Manage ksonnet modules
* [ks param](ks_param.md)	 - Manage ksonnet parameters for components and environments
* [ks pkg](ks_pkg.md)	 - Manage packages and dependencies for the current ksonnet application
* [ks prototype](ks_prototype.md)	 - Instantiate, inspect, and get examples for ksonnet prototypes
* [ks registry](ks_registry.md)	 - Manage registries for current project
* [ks show](ks_show.md)	 - Show expanded manifests for a specific environment.
* [ks upgrade](ks_upgrade.md)	 - Upgrade ks configuration
* [ks validate](ks_validate.md)	 - Check generated component manifests against the server's API
* [ks version](ks_version.md)	 - Print version information for this ksonnet binary
